colour_hdri.utilities.exposure Module — Colour - HDRI 0.1.0 documentation

# colour_hdri.utilities.exposure Module

## Image Exposure Value Computation

Defines image exposure value computation objects:

- `exposure_value()`
- `adjust_exposure()`
- `average_luminance()`

`colour_hdri.utilities.exposure.` `exposure_value`(f_number, exposure_time, iso)

  Computes the exposure value from given image FNumber, Exposure Time and ISO values.

  Parameters: | f_number (array_like) – Image FNumber. exposure_time (array_like) – Image Exposure Time. iso (array_like) – Image ISO.
  Returns: | Image exposure value.
  Return type: | ndarray

  Examples

      >>> exposure_value(8, 1, 100)
      6.0

`colour_hdri.utilities.exposure.` `adjust_exposure`(a, EV)

  Adjusts given array exposure using given \(EV\) exposure value.

  Parameters: | a (array_like) – Array to adjust the exposure. EV (numeric) – Exposure adjustment value.
  Returns: | Exposure adjusted array.
  Return type: | ndarray

  Examples

      >>> adjust_exposure(np.array([0.25, 0.5, 0.75, 1]), 1)
      array([ 0.5,  1. ,  1.5,  2. ])

`colour_hdri.utilities.exposure.` `average_luminance`(f_number, exposure_time, iso, k=12.5)

  Computes the average luminance from given image FNumber, Exposure Time and ISO values.

  Parameters: | f_number (array_like) – Image FNumber. exposure_time (array_like) – Image Exposure Time. iso (array_like) – Image ISO. k (numeric, optional) – Reflected light calibration constant \(K\).
  Returns: | Image average luminance.
  Return type: | ndarray

  References

  [1] | Wikipedia. (n.d.). EV as a measure of luminance and illuminance. Retrieved November 14, 2015, from https://en.wikipedia.org/wiki/Exposure_value#EV_as_a_measure_of_luminance_and_illuminance

  Examples

      >>> average_luminance(8, 1, 100)
      0.125